==> ibl_mobile_sdk-0.4.8.tar.gz: lib/ibl_axd_pro_client.dart <==
import 'package:http/http.dart' as http;
import 'dart:convert';
import 'package:web_socket_channel/web_socket_channel.dart';

import 'dart:async';
import 'dart:io';
class ApiClient {
  final String dataBaseUrl = "https://data.mentor.iblai.tech";
  final String authToken;

  ApiClient({required this.authToken});

  Map<String, String> _headers() {
    return {
      'Content-Type': 'application/json',
      'Authorization': 'Token $authToken',
    };
  }

  Map<String, String> _multipartHeaders() {
    return {
      'Authorization': 'Token $authToken',
    };
  }
  Future<dynamic> apiAiAccountOrgsOrgCredentialGet(String? org) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/credential/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgCredentialPost(String? org, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/credential/'),
      headers: _headers(),
      body: json.encode(body),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgCredentialPatch(String? org, Map body) async {
    final response = await http.patch(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/credential/'),
      headers: _headers(),
      body: json.encode(body),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgPlatformMetadataGet(String? org) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/platform-metadata/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgPlatformMetadataPost(String? org, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/platform-metadata/'),
      headers: _headers(),
      body: json.encode(body),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgPlatformMetadataPut(String? org, Map body) async {
    final response = await http.put(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/platform-metadata/'),
      headers: _headers(),
      body: json.encode(body),
    );

    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgTokensGet(String? org) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/tokens/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdDocumentsDocumentIdRetrieverDocumentsGet(String? documentId, String? org, String? userId) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/documents/$documentId/retriever_documents/'),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdDocumentsDocumentIdRetrieverDocumentsPut(String? documentId, String? org, String? userId, Map body) async {
    final response = await http.put(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/documents/$documentId/retriever_documents/'),
      body: json.encode(body),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdMultilingualRetrieverTrainPost(String? org, String? userId, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/multilingual_retriever_train/'),
      body: json.encode(body),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdPathwaysPathwayRetrieverDocumentsGet(String? org, String? pathway, String? userId) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/pathways/$pathway/retriever_documents/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdRetrieverSearchPost(String? org, String? userId, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/retriever_search/'),
      body: json.encode(body),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> deleteChatSession(String org, String userId, String sessionId) async {
    // Construct the full URL for the DELETE request
    final String url = '$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/sessions/$sessionId/';

    // Prepare the headers
    Map<String, String> headers = _headers();

    // Execute the DELETE request
    final response = await http.delete(
      Uri.parse(url),
      headers: headers,
    );

    // Check the response status code and handle accordingly
    if (response.statusCode == 204) {
      // Successfully deleted with no content in the response body
      print('Chat session deleted successfully');
    } else {
      // If the server did not return a 204 No Content response,
      // then throw an exception.
      throw Exception('Failed to delete chat session. Status code: ${response.statusCode}');
    }
  }

  Future<dynamic> updateChatSessionDetails(String org, String userId, String sessionId, String title) async {
    // Construct the full URL for the PUT request
    final String url = '$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/sessions/$sessionId/';

    // Prepare the headers
    Map<String, String> headers = _headers();

    // Prepare the body of the PUT request
    final body = json.encode({"title": title});

    // Execute the PUT request
    final response = await http.put(
      Uri.parse(url),
      headers: headers,
      body: body,
    );

    // Check the response status code and return the result or throw an error
    if (response.statusCode == 200) {
      // If the server returns an OK response, parse the JSON
      return json.decode(response.body);
    } else {
      // If the server did not return a 200 OK response,
      // then throw an exception.
      throw Exception('Failed to update chat session details. Status code: ${response.statusCode}');
    }
}

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdRetrieverTrainPost(String? org, String? userId, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/retriever_train/'),
      body: json.encode(body),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdSourcesPost(String? org, String? userId, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/sources/'),
      body: json.encode(body),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdTasksTaskIdGet(String? org, String? taskId, String? userId) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/tasks/$taskId/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiMentorOrgsOrgUsersUserIdGet({
    required String? org,
    int? page,
    int? pageSize,
    required String? userId,
    bool? featured, // Optional featured parameter
  }) async {
    var queryParams = {
      if (page != null) 'page': page.toString(),
      if (pageSize != null) 'pageSize': pageSize.toString(),
      if (featured != null) 'featured': featured.toString(), // Add featured to query params if not null
    };

    var queryString = Uri(queryParameters: queryParams).query;

    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/?$queryString'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiMentorOrgsOrgMentorWithSettingsPost(String? org, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/mentor-with-settings/'),
      headers: _headers(),
      body: json.encode(body),
    );
    return json.decode(response.body);
  }

Future<dynamic> updateCustomInstructions(String mentor, String org, Map body) async {
  final response = await http.put(
    Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/mentors/$mentor/settings/'),
    headers: _headers(),
    body: json.encode(body),
  );
  if (response.statusCode == 200) {
    return json.decode(response.body);
  } else {
    throw Exception('Failed to update mentor settings');
  }
}


Future<List<dynamic>> websocket({
  required String baseDataUrl,
  required String mentor,
  required String sessionId,
  required String token,
  required String username,
  String? prompt, // Optional prompt
}) async {
  var channel = WebSocketChannel.connect(
    Uri.parse('wss://$baseDataUrl/ws/langflow/'),
  );

  final controller = StreamController<List<dynamic>>();
  List<dynamic> responses = [];

  // Initial data without the prompt
  final dataWithoutPrompt = {
    "flow": {"name": mentor, "tenant": 'main', "username": username},
    "session_id": sessionId,
    "token": token
  };

  // Send initial data without prompt
  channel.sink.add(json.encode(dataWithoutPrompt));

  // Listen for messages
  channel.stream.listen((message) {
    final data = jsonDecode(message);

    // Handle the server response
    if (data['status'] == 'connected') {
      responses.add(data);

      if (prompt != null) {
        // Send the second message with the prompt
        final dataWithPrompt = {...dataWithoutPrompt, "prompt": prompt};
        channel.sink.add(json.encode(dataWithPrompt));
        prompt = null; // Prevent sending the prompt again
      } else {
        // If no prompt was initially provided, add responses and close the connection
        controller.add(responses);
        channel.sink.close();
      }
    }
  }, onDone: () {
    controller.close(); // Close the controller when the stream is done
  }, onError: (error) {
    controller.addError('Error connecting to server: $error');
    channel.sink.close(); // Close the WebSocket connection on error
  });

  return controller.stream.first; // Return the first (and only) item from the stream
}

  Future<dynamic> voiceWebsocket({
    required String baseWsUrl,
    required String mentor,
    required String tenantKey,
    required String username,
    required String sessionId,
    required String token,
    required List<int> voiceData, // voice data as bytes
  }) async {
    // Establishing a WebSocket connection
    final channel = WebSocketChannel.connect(
      Uri.parse('wss://$baseWsUrl/ws/langflow-voice/'),
    );

    // Prepare auth payload
    final authData = json.encode({
      "flow": {
        "name": mentor,
        "tenant": tenantKey,
        "username": username,
      },
      "session_id": sessionId,
      "token": token,
    });

    // Send auth payload
    channel.sink.add(authData);

    // Convert voice data to Blob if necessary or directly send bytes
    channel.sink.add(voiceData);

    // Listen for server responses
    channel.stream.listen((message) {
      // Process incoming messages
      print('Server: $message');
    }, onDone: () {
      // When the communication is done
      channel.sink.close();
    }, onError: (error) {
      // Handle errors
      print('Error: $error');
      channel.sink.close();
    });
  }


  Future<dynamic> apiAiMentorOrgsOrgMentorsMentorSuggestedPromptsGet({
    required String? mentor,
    required String? org,
  }) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/mentors/$mentor/suggested-prompts/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }
  Future<dynamic> apiAiMentorOrgsOrgMentorsMentorPromptsGet({
    required String? org,
    required String? user_id,
  }) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/users/$user_id/prompt/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiMentorOrgsOrgUsersUserIdRecentMessagesGet({
    required String? org,
    required String? userId,
  }) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/recent-messages/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  // Function for Session ID
  Future<dynamic> apiAiMentorOrgsOrgUsersUserIdSessionidGet({
    required String? endDate,
    required String? org,
    required String? startDate,
    required String? userId,
  }) async {
    var queryParams = {
      'endDate': endDate,
      'startDate': startDate,
    };

    var queryString = Uri(queryParameters: queryParams).query;

    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/sessionid/?$queryString'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }
// Getting pin of messages

  Future<dynamic> apiAiMentorOrgsOrgUsersUserIdPinMessageGet({
    required String org,
    required String userId,
  }) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/pin-message/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiMentorShareSession({
    required String org,
    required String userId,
    required String session_id,
  }) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/sessions/$session_id/?shared=true'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> trainSessionDocument({
    required String org,
    required String userId,
    required String sessionId,
    required File file,
  }) async {
    var uri = Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/train-session-document/sessions/$sessionId/');
    var request = http.MultipartRequest('POST', uri)
      ..headers.addAll(_multipartHeaders()) // Use the multipart headers here
      ..files.add(await http.MultipartFile.fromPath(
        'file', 
        file.path,
      ));

    var streamedResponse = await request.send();
    var response = await http.Response.fromStream(streamedResponse);

    if (response.statusCode == 200) {
      return json.decode(response.body);
    } else {
      throw Exception('Failed to upload file. Status code: ${response.statusCode}');
    }
  }

  // Create a session

  Future<dynamic> apiAiMentorOrgsOrgUsersUserIdSessionsPost({
    required String org,
    required String userId,
    required Map<String, dynamic> body,
  }) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/sessions/'),
      headers: _headers(),
      body: json.encode(body),
    );

    if (response.statusCode >= 200 && response.statusCode < 300) {
      return json.decode(response.body);
    } else {
      throw Exception('Failed to post session. Status code: ${response.statusCode}');
    }
  }
  // Create prompts

  Future<dynamic> apiAiMentorOrgsOrgMentorsMentorSuggestedPromptsPost({
    required String? mentor,
    required String? org,
    required Map<String, dynamic>? body, // Assuming JSON body
  }) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/mentors/$mentor/suggested-prompts/'),
      headers: _headers(),
      body: json.encode(body), // Encode body to JSON string
    );

    if (response.statusCode == 200) {
      // Handle successful response
      return json.decode(response.body);
    } else {
      // Handle error
      throw Exception('Failed to post suggested prompts');
    }
  }
}

==> ibl_mobile_sdk-0.5.6.tar.gz: lib/ibl_axd_pro_client.dart <==
import 'package:http/http.dart' as http;
import 'dart:convert';
import 'package:web_socket_channel/web_socket_channel.dart';
import 'package:flutter_sound/flutter_sound.dart';
import 'package:path_provider/path_provider.dart';
import 'dart:async';
import 'dart:io';
class ApiClient {
  final String dataBaseUrl = "https://data.mentor.iblai.tech";
  final String authToken;
  final FlutterSoundRecorder _audioRecorder = FlutterSoundRecorder();

  ApiClient({required this.authToken});

  Map<String, String> _headers() {
    return {
      'Content-Type': 'application/json',
      'Authorization': 'Token $authToken',
    };
  }

  Map<String, String> _multipartHeaders() {
    return {
      'Authorization': 'Token $authToken',
    };
  }
  Future<dynamic> apiAiAccountOrgsOrgCredentialGet(String? org) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/credential/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgCredentialPost(String? org, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/credential/'),
      headers: _headers(),
      body: json.encode(body),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgCredentialPatch(String? org, Map body) async {
    final response = await http.patch(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/credential/'),
      headers: _headers(),
      body: json.encode(body),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgPlatformMetadataGet(String? org) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/platform-metadata/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgPlatformMetadataPost(String? org, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/platform-metadata/'),
      headers: _headers(),
      body: json.encode(body),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgPlatformMetadataPut(String? org, Map body) async {
    final response = await http.put(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/platform-metadata/'),
      headers: _headers(),
      body: json.encode(body),
    );

    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgTokensGet(String? org) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/tokens/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdDocumentsDocumentIdRetrieverDocumentsGet(String? documentId, String? org, String? userId) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/documents/$documentId/retriever_documents/'),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdDocumentsDocumentIdRetrieverDocumentsPut(String? documentId, String? org, String? userId, Map body) async {
    final response = await http.put(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/documents/$documentId/retriever_documents/'),
      body: json.encode(body),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdMultilingualRetrieverTrainPost(String? org, String? userId, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/multilingual_retriever_train/'),
      body: json.encode(body),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdPathwaysPathwayRetrieverDocumentsGet(String? org, String? pathway, String? userId) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/pathways/$pathway/retriever_documents/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdRetrieverSearchPost(String? org, String? userId, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/retriever_search/'),
      body: json.encode(body),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> deleteChatSession({required String org, required String userId, required String ? sessionId}) async {
    // Construct the full URL for the DELETE request
    final String url = '$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/sessions/$sessionId/';

    // Prepare the headers
    Map<String, String> headers = _headers();

    // Execute the DELETE request
    final response = await http.delete(
      Uri.parse(url),
      headers: headers,
    );

    // Check the response status code and handle accordingly
    if (response.statusCode == 204) {
      // Successfully deleted with no content in the response body
      print('Chat session deleted successfully');
    } else {
      // If the server did not return a 204 No Content response,
      // then throw an exception.
      throw Exception('Failed to delete chat session. Status code: ${response.statusCode}');
    }
  }
  Future<void> initRecorder() async {
    await _audioRecorder.openAudioSession();
    final directory = await getApplicationDocumentsDirectory();
    final filePath = '${directory.path}/recorded_audio.m4a';
    await _audioRecorder.startRecorder(toFile: filePath);
  }

  // Stop the recorder and get the voice data
  Future<List<int>> stopRecorderAndGetVoiceData() async {
    final String? filePath = await _audioRecorder.stopRecorder();
    final voiceData = await File(filePath!).readAsBytes();
    await _audioRecorder.closeAudioSession();
    return voiceData;
  }

  Future<dynamic> updateChatSessionDetails({ required String org, required String userId, required String sessionId, required String title}) async {
    // Construct the full URL for the PUT request
    final String url = '$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/sessions/$sessionId/';

    // Prepare the headers
    Map<String, String> headers = _headers();

    // Prepare the body of the PUT request
    final body = json.encode({"title": title});

    // Execute the PUT request
    final response = await http.put(
      Uri.parse(url),
      headers: headers,
      body: body,
    );

    // Check the response status code and return the result or throw an error
    if (response.statusCode == 200) {
      // If the server returns an OK response, parse the JSON
      return json.decode(response.body);
    } else {
      // If the server did not return a 200 OK response,
      // then throw an exception.
      throw Exception('Failed to update chat session details. Status code: ${response.statusCode}');
    }
}

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdRetrieverTrainPost(String? org, String? userId, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/retriever_train/'),
      body: json.encode(body),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdSourcesPost(String? org, String? userId, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/sources/'),
      body: json.encode(body),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdTasksTaskIdGet(String? org, String? taskId, String? userId) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/tasks/$taskId/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiMentorOrgsOrgUsersUserIdGet({
    required String? org,
    int? page,
    int? pageSize,
    required String? userId,
    bool? featured, // Optional featured parameter
  }) async {
    var queryParams = {
      if (page != null) 'page': page.toString(),
      if (pageSize != null) 'pageSize': pageSize.toString(),
      if (featured != null) 'featured': featured.toString(), // Add featured to query params if not null
    };

    var queryString = Uri(queryParameters: queryParams).query;

    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/?$queryString'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiMentorOrgsOrgMentorWithSettingsPost(String? org, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/mentor-with-settings/'),
      headers: _headers(),
      body: json.encode(body),
    );
    return json.decode(response.body);
  }

Future<dynamic> updateCustomInstructions({required String mentor, required String org, required Map body}) async {
  final response = await http.put(
    Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/mentors/$mentor/settings/'),
    headers: _headers(),
    body: json.encode(body),
  );
  if (response.statusCode == 200) {
    return json.decode(response.body);
  } else {
    throw Exception('Failed to update mentor settings');
  }
}


Future<List<dynamic>> websocket({
  required String baseDataUrl,
  required String mentor,
  required String sessionId,
  required String token,
  required String username,
  String? prompt, // Optional prompt
}) async {
  var channel = WebSocketChannel.connect(
    Uri.parse('wss://$baseDataUrl/ws/langflow/'),
  );

  final controller = StreamController<List<dynamic>>();
  List<dynamic> responses = [];

  // Initial data without the prompt
  final dataWithoutPrompt = {
    "flow": {"name": mentor, "tenant": 'main', "username": username},
    "session_id": sessionId,
    "token": token
  };

  // Send initial data without prompt
  channel.sink.add(json.encode(dataWithoutPrompt));

  // Listen for messages
  channel.stream.listen((message) {
    final data = jsonDecode(message);

    // Handle the server response
    if (data['status'] == 'connected') {
      responses.add(data);

      if (prompt != null) {
        // Send the second message with the prompt
        final dataWithPrompt = {...dataWithoutPrompt, "prompt": prompt};
        channel.sink.add(json.encode(dataWithPrompt));
        prompt = null; // Prevent sending the prompt again
      } else {
        // If no prompt was initially provided, add responses and close the connection
        controller.add(responses);
        channel.sink.close();
      }
    }
  }, onDone: () {
    controller.close(); // Close the controller when the stream is done
  }, onError: (error) {
    controller.addError('Error connecting to server: $error');
    channel.sink.close(); // Close the WebSocket connection on error
  });

  return controller.stream.first; // Return the first (and only) item from the stream
}

  Future<dynamic> voiceWebsocket({
    required String baseWsUrl,
    required String mentor,
    required String tenantKey,
    required String username,
    required String sessionId,
    required String token,
    required List<int> voiceData, // voice data as bytes
  }) async {
    // Establishing a WebSocket connection
    final channel = WebSocketChannel.connect(
      Uri.parse('wss://$baseWsUrl/ws/langflow-voice/'),
    );

    // Prepare auth payload
    final authData = json.encode({
      "flow": {
        "name": mentor,
        "tenant": tenantKey,
        "username": username,
      },
      "session_id": sessionId,
      "token": token,
    });

    // Send auth payload
    channel.sink.add(authData);

    // Convert voice data to Blob if necessary or directly send bytes
    channel.sink.add(voiceData);

    // Listen for server responses
    channel.stream.listen((message) {
      // Process incoming messages
      print('Server: $message');
    }, onDone: () {
      // When the communication is done
      channel.sink.close();
    }, onError: (error) {
      // Handle errors
      print('Error: $error');
      channel.sink.close();
    });
  }


  Future<dynamic> apiAiMentorOrgsOrgMentorsMentorSuggestedPromptsGet({
    required String? mentor,
    required String? org,
  }) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/mentors/$mentor/suggested-prompts/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }
  Future<dynamic> apiAiMentorOrgsOrgMentorsMentorPromptsGet({
    required String? org,
    required String? user_id,
  }) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/users/$user_id/prompt/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiMentorOrgsOrgUsersUserIdRecentMessagesGet({
    required String? org,
    required String? userId,
  }) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/recent-messages/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  // Function for Session ID
  Future<dynamic> apiAiMentorOrgsOrgUsersUserIdSessionidGet({
    required String? endDate,
    required String? org,
    required String? startDate,
    required String? userId,
  }) async {
    var queryParams = {
      'endDate': endDate,
      'startDate': startDate,
    };

    var queryString = Uri(queryParameters: queryParams).query;

    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/sessionid/?$queryString'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }
// Getting pin of messages

  Future<dynamic> apiAiMentorOrgsOrgUsersUserIdPinMessageGet({
    required String org,
    required String userId,
  }) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/pin-message/'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiMentorShareSession({
    required String org,
    required String userId,
    required String session_id,
  }) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/sessions/$session_id/?shared=true'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> trainSessionDocument({
    required String org,
    required String userId,
    required String sessionId,
    required File file,
  }) async {
    var uri = Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/train-session-document/sessions/$sessionId/');
    var request = http.MultipartRequest('POST', uri)
      ..headers.addAll(_multipartHeaders()) // Use the multipart headers here
      ..files.add(await http.MultipartFile.fromPath(
        'file', 
        file.path,
      ));

    var streamedResponse = await request.send();
    var response = await http.Response.fromStream(streamedResponse);

    if (response.statusCode == 200) {
      return json.decode(response.body);
    } else {
      throw Exception('Failed to upload file. Status code: ${response.statusCode}');
    }
  }

  // Create a session

  Future<dynamic> apiAiMentorOrgsOrgUsersUserIdSessionsPost({
    required String org,
    required String userId,
    required Map<String, dynamic> body,
  }) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/sessions/'),
      headers: _headers(),
      body: json.encode(body),
    );

    if (response.statusCode >= 200 && response.statusCode < 300) {
      return json.decode(response.body);
    } else {
      throw Exception('Failed to post session. Status code: ${response.statusCode}');
    }
  }
  // Create prompts

  Future<dynamic> apiAiMentorOrgsOrgMentorsMentorSuggestedPromptsPost({
    required String? mentor,
    required String? org,
    required Map<String, dynamic>? body, // Assuming JSON body
  }) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/mentors/$mentor/suggested-prompts/'),
      headers: _headers(),
      body: json.encode(body), // Encode body to JSON string
    );

    if (response.statusCode == 200) {
      // Handle successful response
      return json.decode(response.body);
    } else {
      // Handle error
      throw Exception('Failed to post suggested prompts');
    }
  }
}
